==> base-domain-0.0.3-20170420.070041-134-sources.jar: com/thebeastshop/scm/vo/SoPackageDeliveryInfoVO.java <==
package com.thebeastshop.scm.vo;

import pers.richard.ormybatis.domain.core.AbstractDomain;

import com.thebeastshop.scm.po.SoPackageDeliveryInfo;

/**
 * 包裹配送vo
 * 
 * @author 徐玲玲
 *
 * 2016年8月25日
 */
public class SoPackageDeliveryInfoVO extends AbstractDomain{
    private Integer id;
    private Integer packageId;
	private Integer districtId;
	private String address;
	private String zipCode;
	private String circuitDesc;
	private String companyName;
	private Integer title;
	private String receiver;
	private String receiverPhone;
	private Integer expressType;
	private String deliveryCode;
	private Integer isEbill;
	private String ext1;
	private String ext2;
	private String ext3;
	private String ext4;
	private String ext5;

	private String districtName;		// 地址前缀（省市区）

    // 快递类型
    public String getExpressTypeName() {
        return 	expressType == null ? "" :
        		expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SHOP) ? "店送" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_FEDEX) ? "联邦" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SF_AIR) ? "顺丰(空运)" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SF_LAND) ? "顺丰(陆运)":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_YTO) ? "圆通" : 
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SELF) ? "自送":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_HT) ? "海淘顺丰": "";
    }

    // 称谓
    public String getTitleName(){
        return 	title == null ? "":
                title.equals(SoPackageDeliveryInfo.TITLE_MR) ? "先生" :
                title.equals(SoPackageDeliveryInfo.TITLE_MS) ? "女士" :
                title.equals(SoPackageDeliveryInfo.TITLE_MISS) ? "小姐" :
                title.equals(SoPackageDeliveryInfo.TITLE_UNKNOW) ? "保密" : "";
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getPackageId() {
        return packageId;
    }

    public void setPackageId(Integer packageId) {
        this.packageId = packageId;
    }

    public Integer getDistrictId() {
        return districtId;
    }

    public void setDistrictId(Integer districtId) {
        this.districtId = districtId;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getZipCode() {
        return zipCode;
    }

    public void setZipCode(String zipCode) {
        this.zipCode = zipCode;
    }

    public String getCircuitDesc() {
        return circuitDesc;
    }

    public void setCircuitDesc(String circuitDesc) {
        this.circuitDesc = circuitDesc;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Integer getTitle() {
        return title;
    }

    public void setTitle(Integer title) {
        this.title = title;
    }

    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getReceiverPhone() {
        return receiverPhone;
    }

    public void setReceiverPhone(String receiverPhone) {
        this.receiverPhone = receiverPhone;
    }

    public String getDeliveryCode() {
        return deliveryCode;
    }

    public void setDeliveryCode(String deliveryCode) {
        this.deliveryCode = deliveryCode;
    }

    public Integer getExpressType() {
        return expressType;
    }

    public void setExpressType(Integer expressType) {
        this.expressType = expressType;
    }

    public Integer getIsEbill() {
        return isEbill;
    }

    public void setIsEbill(Integer isEbill) {
        this.isEbill = isEbill;
    }

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getExt3() {
        return ext3;
    }

    public void setExt3(String ext3) {
        this.ext3 = ext3;
    }

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

	public String getDistrictName() {
		return districtName;
	}

	public void setDistrictName(String districtName) {
		this.districtName = districtName;
	}
}

==> base-domain-1.1.38-sources.jar: com/thebeastshop/scm/vo/SoPackageDeliveryInfoVO.java <==
package com.thebeastshop.scm.vo;

import pers.richard.ormybatis.domain.core.AbstractDomain;

import com.thebeastshop.scm.po.SoPackageDeliveryInfo;

/**
 * 包裹配送vo
 * 
 * @author 徐玲玲
 *
 * 2016年8月25日
 */
public class SoPackageDeliveryInfoVO extends AbstractDomain{
    private Integer id;
    private Integer packageId;
	private Integer districtId;
	private String address;
	private String zipCode;
	private String circuitDesc;
	private String companyName;
	private Integer title;
	private String receiver;
	private String receiverPhone;
	private Integer expressType;
	private String deliveryCode;
	private Integer isEbill;
	private String ext1;
	private String ext2;
	private String ext3;
	private String ext4;
	private String ext5;

	private String districtName;		// 地址前缀（省市区）

    // 快递类型
    public String getExpressTypeName() {
        return 	expressType == null ? "" :
        		expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SHOP) ? "店送" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_FEDEX) ? "联邦" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SF_AIR) ? "顺丰(空运)" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SF_LAND) ? "顺丰(陆运)":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_YTO) ? "圆通" : 
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_DEPPON) ? "德邦" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SELF) ? "自送":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_HT) ? "海淘顺丰":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_ZHONGTONG) ? "中通" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_ANXIANDA) ? "安鲜达" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SHANSONG) ? "闪送" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_SF_COLD) ? "顺丰冷链":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_ST) ? "申通" :
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_YD) ? "韵达":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_KYSS) ? "跨越速运":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_JDKY) ? "京东空运":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_JDLY) ? "京东陆运":
                expressType.equals(SoPackageDeliveryInfo.EXPRESS_TYPE_JDTCS) ? "京东同城送": "";
    }

    // 称谓
    public String getTitleName(){
        return 	title == null ? "":
                title.equals(SoPackageDeliveryInfo.TITLE_MR) ? "先生" :
                title.equals(SoPackageDeliveryInfo.TITLE_MS) ? "女士" :
                title.equals(SoPackageDeliveryInfo.TITLE_MISS) ? "小姐" :
                title.equals(SoPackageDeliveryInfo.TITLE_UNKNOW) ? "保密" : "";
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getPackageId() {
        return packageId;
    }

    public void setPackageId(Integer packageId) {
        this.packageId = packageId;
    }

    public Integer getDistrictId() {
        return districtId;
    }

    public void setDistrictId(Integer districtId) {
        this.districtId = districtId;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getZipCode() {
        return zipCode;
    }

    public void setZipCode(String zipCode) {
        this.zipCode = zipCode;
    }

    public String getCircuitDesc() {
        return circuitDesc;
    }

    public void setCircuitDesc(String circuitDesc) {
        this.circuitDesc = circuitDesc;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Integer getTitle() {
        return title;
    }

    public void setTitle(Integer title) {
        this.title = title;
    }

    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getReceiverPhone() {
        return receiverPhone;
    }

    public void setReceiverPhone(String receiverPhone) {
        this.receiverPhone = receiverPhone;
    }

    public String getDeliveryCode() {
        return deliveryCode;
    }

    public void setDeliveryCode(String deliveryCode) {
        this.deliveryCode = deliveryCode;
    }

    public Integer getExpressType() {
        return expressType;
    }

    public void setExpressType(Integer expressType) {
        this.expressType = expressType;
    }

    public Integer getIsEbill() {
        return isEbill;
    }

    public void setIsEbill(Integer isEbill) {
        this.isEbill = isEbill;
    }

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getExt3() {
        return ext3;
    }

    public void setExt3(String ext3) {
        this.ext3 = ext3;
    }

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

	public String getDistrictName() {
		return districtName;
	}

	public void setDistrictName(String districtName) {
		this.districtName = districtName;
	}
}
